@@ -1,19 +1,18 @@
 # (C) 2021 GoodData Corporation
 from pathlib import Path
 
-import vcr
+from tests_support.vcrpy_utils import get_vcr
 
 from gooddata_pandas import DataFrameFactory
 from gooddata_sdk import PositiveAttributeFilter
-from tests import VCR_MATCH_ON
+
+gd_vcr = get_vcr()
 
 _current_dir = Path(__file__).parent.absolute()
 _fixtures_dir = _current_dir / "fixtures"
 
-gd_vcr = vcr.VCR(filter_headers=["authorization", "user-agent"], serializer="json", match_on=VCR_MATCH_ON)
 
-
-@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_metrics.json"))
+@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_metrics.yaml"))
 def test_not_indexed_metrics(gdf: DataFrameFactory):
     df = gdf.not_indexed(
         columns=dict(
@@ -28,11 +27,11 @@ def test_not_indexed_metrics(gdf: DataFrameFactory):
     assert df.columns[1] == "order_count"
 
 
-@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_metrics_and_labels.json"))
+@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_metrics_and_labels.yaml"))
 def test_not_indexed_metrics_and_labels(gdf: DataFrameFactory):
     df = gdf.not_indexed(
         columns=dict(
-            reg="label/customers.region",
+            reg="label/region",
             order_amount="metric/order_amount",
             order_count="metric/amount_of_orders",
         )
@@ -45,11 +44,11 @@ def test_not_indexed_metrics_and_labels(gdf: DataFrameFactory):
     assert df.columns[2] == "order_count"
 
 
-@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_filtered_metrics_and_labels.json"))
+@gd_vcr.use_cassette(str(_fixtures_dir / "not_indexed_filtered_metrics_and_labels.yaml"))
 def test_not_indexed_filtered_metrics_and_labels(gdf: DataFrameFactory):
     df = gdf.not_indexed(
         columns=dict(
-            reg="label/customers.region",
+            reg="label/region",
             order_amount="metric/order_amount",
             order_count="metric/amount_of_orders",
         ),
@@ -61,3 +60,19 @@ def test_not_indexed_filtered_metrics_and_labels(gdf: DataFrameFactory):
     assert df.columns[0] == "reg"
     assert df.columns[1] == "order_amount"
     assert df.columns[2] == "order_count"
+
+
+@gd_vcr.use_cassette(str(_fixtures_dir / "empty_not_indexed_dataframe.yaml"))
+def test_empty_not_indexed_dataframe(gdf: DataFrameFactory):
+    df = gdf.not_indexed(
+        columns=dict(
+            product_name="label/product_name",
+            amount_of_top_customers="metric/amount_of_top_customers",
+            total_revenue="metric/total_revenue-no_filters",
+        ),
+    )
+
+    assert df.empty
+    assert df.columns[0] == "product_name"
+    assert df.columns[1] == "amount_of_top_customers"
+    assert df.columns[2] == "total_revenue"
